@@ -69,9 +69,8 @@ case "$switch" in
      dcs clonezilla-start
 
      echo "$msg_delimiter_star_line"
-     echo -n $msg_press_enter_to_continue
-     # force to use < /dev/stdin to avoid some bug about tftpd-hpa which will lock file handle 0.
-     read < /dev/stdin
+     echo "$msg_do_not_close_window_until_clone_finish"
+     /bin/bash
      ;;
    "stop")
      drbl-ocs stop
